;**CLM Tutorial 2014***********************************
;** NCL script written by Sanjiv Kumar; Email: sanjiv@cola.iges.org
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

;*********************specify the case name here******

caseName = "CLM2014Tutorial_5yr1850test"

caseName2 = "clm4_5_07_Control"


;**********************specify the model output directory****

modInDir = "/glade/scratch/dll/archive/CLM2014Tutorial_5yr1850test/lnd/hist"

modInDir2 = "/glade/scratch/dll/archive/clm4_5_07_Control/lnd/hist"

;*********************** make the file list you want to add ********

flis = systemfunc("ls "+modInDir+"/"+caseName+".clm2.h0.*.nc")

flis2 = systemfunc("ls "+modInDir2+"/"+caseName2+".clm2.h0.*.nc")

 ;print(flis)

 ;exit 
 ;a useful command for debugging your script

;** adding all those file***********

f1 = addfiles(flis, "r")

ListSetType(f1, "cat")

f2 = addfiles(flis2, "r")

ListSetType(f2, "cat")


;*********************************

var1 = f1[:]->TSA

printVarSummary(var1)

var2 = f2[0:59]->TSA

printVarSummary(var2)


;*** to change unit from K to degree celcius***

var1 = var1 - 273.15

var2 = var2 - 273.15

var1@units = "degree C"
var2@units = "degree C"

;*****Note that all time steps are added *******

var1_mon_mean = clmMonTLL(var1)
printVarSummary(var1_mon_mean)

var1_mon_std = stdMonTLL(var1)
printVarSummary(var1_mon_std)


var2_mon_mean = clmMonTLL(var2)
printVarSummary(var2_mon_mean)

var2_mon_std = stdMonTLL(var2)
printVarSummary(var2_mon_std)


;*****************making annual time seris****

 var1_ann = var1(0:4, :, :)  ;***this way new variables have necessary dimensions e.g. lat and lon
              
                            ;*** you can cahnge time dimensions depending upon the number of years for your run

 var2_ann = var2(0:4, :, :)

 do i = 0, 4
    sti = i*12
    endi = sti + 11
    var1_ann(i, :, :) = (/dim_avg_n_Wrap(var1(sti:endi, :, :), 0)/)
    var2_ann(i, :, :) = (/dim_avg_n_Wrap(var2(sti:endi, :, :), 0)/)
 end do

 var1_ann_avg = dim_avg_n_Wrap(var1_ann, 0)     ;**** _Wrap is necessary because that way it also copies the metadata
 printVarSummary(var1_ann_avg)
 
 var1_ann_std = dim_stddev_n_Wrap(var1_ann, 0)
 printVarSummary(var1_ann_std)

 var2_ann_avg = dim_avg_n_Wrap(var2_ann, 0)     ;**** _Wrap is necessary because that way it also copies the metadata
 printVarSummary(var1_ann_avg)

 var2_ann_std = dim_stddev_n_Wrap(var2_ann, 0)
 printVarSummary(var1_ann_std)


 var_diff = var1_ann_avg
 var_diff = var2_ann_avg -  var1_ann_avg

 var_diff_sig = var1_ann_avg
 var_diff_sig = ttest(var1_ann_avg, var1_ann_std^2.0, 5, var2_ann_avg, var2_ann_std^2.0, 5, True, False) 
 var_diff_sig  = where(var_diff_sig.le.0.05, 2.5, 0.5)  ;***here i am assiging 2.5 value for sig. diff



;***Now we have two dimensional vairables var1_ann_avg, and var1_ann_std****************************************
;***we want to plot them ****************************************************************************************

 wks = gsn_open_wks("x11", "climatology_diff_plot")

 gsn_define_colormap(wks, "sunshine_diff_12lev")     ; you can select your favorate coolor from NCL color tables

 ;gsn_reverse_colormap(wks)  ;****incase you want to reverse the color map

 res = True                  ; Define resources for the plot

 res@gsnDraw            = False             ; don't draw yet           ; these resources are necessary when you draw a panel plot
 res@gsnFrame           = False             ; don't advance frame yet

 res@gsnMaximize = True
 
 res@mpLimitMode          = "LatLon"      ; these resources are helful if you want to plot only a specfic region
 res@mpMinLatF            = 10
 res@mpMaxLatF            = 75
 res@mpMinLonF            = -170
 res@mpMaxLonF            =  -50

 res@mpOutlineBoundarySets = "Geophysical"
 res@mpGeophysicalLineColor = "black"
 res@mpUSStateLineColor = "black"
 
 res@pmTickMarkDisplayMode = "Always"

 res@cnFillOn = True
 res@cnLinesOn = False
 ;res@cnFillMode = "RasterFill"
 res@cnLineLabelsOn = False

 res@gsnSpreadColors = True

 res@lbOrientation = "Horizontal"

 res@lbBoxLinesOn         = False           ; Turn off labelbar box lines
 res@lbLabelAutoStride    = True            ; Control labelbar labels.


 ; res@lbLabelBarOn = False                 ; becomes useful in a panel plot


 ;*******SECTION A*******************************************
 ; ***first plot by commenting all the res in section A****
 ; *** the decide which maximum and minimum value you want to assign *****
 ; **** accordingly decide the min, max and stide for manual cn level selction *****
 res@cnLevelSelectionMode = "ManualLevels"
 res@cnMinLevelValF =  -2.5
 res@cnMaxLevelValF =  2.5
 res@cnLevelSpacingF = 0.5

 ;*********** END OF SECTION A****************************************

  plot1 = new(1, graphic)                    ; if you have more than one plot then this is useful

  plot1(0) = gsn_csm_contour_map(wks, var_diff, res)

 ;****Now we will do the controur plot for std***********************

 res2 = True                                  

 res2@gsnDraw = False  ; Do not draw plots
 res2@gsnFrame = False ; Do not advance the frame


 ;res2@mpLimitMode          = "LatLon"      ; these resources are helful if you want to plot only a specfic region
 ;res2@mpMinLatF            = 10
 ;res2@mpMaxLatF            = 75
 ;res2@mpMinLonF            = -170
 ;res2@mpMaxLonF            =  -50

 ;***first plot it by commenting out this secti*********

  res2@gsnMaximize = True

   res2@cnInfoLabelOn       = False       ; turn off info label
   res2@cnLinesOn           = False       ; do not draw contour lines
   res2@cnLineLabelsOn      = False       ; do not draw contour labels
   res2@cnFillScaleF        = 0.7         ; add extra density
   ;res2@cnFillMode = "RasterFill"

   res2@cnLevelSelectionMode = "ManualLevels"
   res2@cnMinLevelValF =  0.0
   res2@cnMaxLevelValF =  3.0
   res2@cnLevelSpacingF =  1.0

   opt = True
   opt@gsnShadeFillType = "pattern"      ; pattern fill
   opt@gsnShadeHigh = 17       ; use pattern #2
   ;opt@gsnShadeLow = 3



 ;***Now draw contour plot for the plot

 plot2 = plot1

 delete(var_diff_sig@long_name)
 delete(var_diff_sig@units)

 plot2(0) = gsn_csm_contour(wks, var_diff_sig, res2)  ; create pl
 plot2(0) = gsn_contour_shade(plot2(0), -9999.0, 2.0, opt)


 ;***Overlay the plot*********

 overlay(plot1(0), plot2(0))

 draw(plot1(0))
 frame(wks)




