;**CLM Tutorial 2014***********************************
;** NCL script written by Sanjiv Kumar; Email: sanjiv@cola.iges.org

load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

;*********************specify the case name here******

caseName = "CLM2014Tutorial_5yr1850test"

;**********************specify the model output directory****

modInDir = "/glade/scratch/dll/archive/CLM2014Tutorial_5yr1850test/lnd/hist"

;*********************** make the file list you want to add ********

flis = systemfunc("ls "+modInDir+"/"+caseName+".clm2.h0.*.nc")

 ;print(flis)

 ;exit 
 ;a useful command for debugging your script

;** adding all those file***********

f1 = addfiles(flis, "r")

ListSetType(f1, "cat")

;*********************************

var1 = f1[:]->TSA

printVarSummary(var1)

;********************Add a history file to extarct some fixed variable*****

 f3 = addfile(modInDir+"/"+caseName+".clm2.h0.0001-01.nc", "r")
 
 ar = f3->area
 lf = f3->landfrac

 arwt = ar
 arwt = ar * lf

 lm = f3->landmask 

 lat = f3->lat
 lon = f3->lon

;*** to change unit from K to degree celcius***

var1 = var1 - 273.15

var1@units = "degree C"

; var1 = mask(var1, lm.eq.0, False)

;*****Note that all time steps are added *******

var1_mon_mean = clmMonTLL(var1)
printVarSummary(var1_mon_mean)

var1_mon_std = stdMonTLL(var1)
printVarSummary(var1_mon_std)

;*****Enter the regional extent*************************

  nReg = 1

  lonRegL = (/262.0/)
  lonRegR = (/280.0/)

  latRegL = (/35.0/)
  latRegH = (/50.0/)


  P1 = new((/12, 2/), "float", -9999.0)
  P1(:, 0) = wgt_areaave2(var1_mon_mean(:, {latRegL(0):latRegH(0)}, {lonRegL(0):lonRegR(0)}), arwt({latRegL(0):latRegH(0)}, {lonRegL(0):lonRegR(0)}), 0) 
  P1(:, 1) = wgt_areaave2(var1_mon_std(:, {latRegL(0):latRegH(0)}, {lonRegL(0):lonRegR(0)}), arwt({latRegL(0):latRegH(0)}, {lonRegL(0):lonRegR(0)}), 0)

  opt1 = True
  opt1@fout = "mw_usa_temp_mon_climo.txt"
  fmtx = "2f15.8"
  write_matrix(P1, fmtx, opt1)




;*****************making annual time seris****

 var1_ann = var1(0:4, :, :)  ;***this way new variables have necessary dimensions e.g. lat and lon
                             ;*** you can cahnge time dimensions depending upon the number of years for your run

 do i = 0, 4
    sti = i*12
    endi = sti + 11
    var1_ann(i, :, :) = (/dim_avg_n_Wrap(var1(sti:endi, :, :), 0)/)
 end do

 var1_ann_avg = dim_avg_n_Wrap(var1_ann, 0)     ;**** _Wrap is necessary because that way it also copies the metadata
 printVarSummary(var1_ann_avg)
 
 var1_ann_std = dim_stddev_n_Wrap(var1_ann, 0)

 printVarSummary(var1_ann_std)

;***Now we have two dimensional vairables var1_ann_avg, and var1_ann_std****************************************
;***we want to plot them ****************************************************************************************

 wks = gsn_open_wks("x11", "climatology_plot1_mw_usa")

 gsn_define_colormap(wks, "cosam")     ; you can select your favorate coolor from NCL color tables

 ;gsn_reverse_colormap(wks)  ;****incase you want to reverse the color map

 res = True                  ; Define resources for the plot

 res@gsnDraw            = False             ; don't draw yet           ; these resources are necessary when you draw a panel plot
 res@gsnFrame           = False             ; don't advance frame yet

 res@gsnMaximize = True
 
 res@mpLimitMode          = "LatLon"      ; these resources are helful if you want to plot only a specfic region
 res@mpMinLatF            = 10
 res@mpMaxLatF            = 75
 res@mpMinLonF            = -170
 res@mpMaxLonF            =  -50

 res@mpOutlineBoundarySets = "Geophysical"
 res@mpGeophysicalLineColor = "black"
 res@mpUSStateLineColor = "black"
 
 res@pmTickMarkDisplayMode = "Always"

 res@cnFillOn = True
 res@cnLinesOn = False
 res@cnFillMode = "RasterFill"
 res@cnLineLabelsOn = False

 res@gsnSpreadColors = True

 res@lbOrientation = "Horizontal"

 res@lbBoxLinesOn         = False           ; Turn off labelbar box lines
 res@lbLabelAutoStride    = True            ; Control labelbar labels.


 ; res@lbLabelBarOn = False                 ; becomes useful in a panel plot


 ;*******SECTION A*******************************************
 ; ***first plot by commenting all the res in section A****
 ; *** the decide which maximum and minimum value you want to assign *****
 ; **** accordingly decide the min, max and stide for manual cn level selction *****
 res@cnLevelSelectionMode = "ManualLevels"
 res@cnMinLevelValF =  -40.0
 res@cnMaxLevelValF =  40.0
 res@cnLevelSpacingF = 10.0

 ;*********** END OF SECTION A****************************************

  plot = new(2, graphic)                    ; if you have more than one plot then this is useful

 plot(0) = gsn_csm_contour_map(wks, var1_ann_avg, res)

  gsres = True
  gsres@gsLineColor = "black"
  gsres@gsLineThicknessF = 5.0

  dum1 = new(1, graphic)
 
  do i = 0, 0
     dum1(i) = gsn_add_polyline(wks, plot(0), (/lon({lonRegL(i)}), lon({lonRegR(i)}), lon({lonRegR(i)}), lon({lonRegL(i)}), lon({lonRegL(i)})/), (/lat({latRegL(i)}), lat({latRegL(i)}), lat({latRegH(i)}), lat({latRegH(i)}), lat({latRegL(i)})/), gsres)
  end do

;************************************************************************
 draw(plot(0))
 frame(wks)







