;**CLM Tutorial 2014***********************************
;** NCL script written by Sanjiv Kumar; Email: sanjiv@cola.iges.org
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

;*********************specify the case name here******

caseName = "CLM2014Tutorial_20yr2000SP_n02_clm4_5_57"

;**********************specify the model output directory****

modInDir = "/glade/p/cesm/lmwg/CLM2014_tutorial_space/20yrSimulations/2000SP/lnd"

;*********************** make the file list you want to add ********

flis = systemfunc("ls "+modInDir+"/"+caseName+".clm2.h0.*.nc")

 ;print(flis)

 ;exit 
 ;a useful command for debugging your script

;** adding all those file***********

f1 = addfiles(flis, "r")

ListSetType(f1, "cat")

;*********************************

var1a = f1[180:239]->FCEV    ; canopy evaporation
var1b = f1[180:239]->FCTR    ; canopy transpiration
var1c = f1[180:239]->FGEV    ; ground evaporation

var1 = var1a
var1 = var1a + var1b + var1c
var1@long_name = "Evapotranspiration"

printVarSummary(var1)

;********************Add a history file to extarct some fixed variable*****

 f3 = addfile(modInDir+"/"+caseName+".clm2.h0.0001-01.nc", "r")
 
 ar = f3->area
 lf = f3->landfrac

 arwt = ar
 arwt = ar * lf

 lm = f3->landmask 

 lat = f3->lat
 lon = f3->lon

;*** to change unit from K to degree celcius***

;var1 = var1 - 273.15

;var1@units = "degree Celcius"

; var1 = mask(var1, lm.eq.0, False)

;*****Note that all time steps are added *******

var1_mon_mean = clmMonTLL(var1)
printVarSummary(var1_mon_mean)

var1_mon_std = stdMonTLL(var1)
printVarSummary(var1_mon_std)

;*****Enter the regional extent*************************

  nReg = 1

  lonRegL = (/262.0/)
  lonRegR = (/280.0/)

  latRegL = (/35.0/)
  latRegH = (/50.0/)


  P1 = new((/12, 2/), "float", -9999.0)
  P1(:, 0) = wgt_areaave2(var1_mon_mean(:, {latRegL(0):latRegH(0)}, {lonRegL(0):lonRegR(0)}), arwt({latRegL(0):latRegH(0)}, {lonRegL(0):lonRegR(0)}), 0) 
  P1(:, 1) = wgt_areaave2(var1_mon_std(:, {latRegL(0):latRegH(0)}, {lonRegL(0):lonRegR(0)}), arwt({latRegL(0):latRegH(0)}, {lonRegL(0):lonRegR(0)}), 0)

  opt1 = True
  opt1@fout = "mw_usa_ET_mon_climo.txt"
  fmtx = "2f15.8"
  write_matrix(P1, fmtx, opt1)


;*******************Seasonality Extract from Point Location ******************

 nSt = 1
 StLat = (/45.5598/)
 StLon = (/275.2862/)

 ilat = ind_nearest_coord(StLat(0), lat, 0)
 ilon = ind_nearest_coord(StLon(0), lon, 0)
 
 print("ilat="+ilat+" StLat ="+StLat(0)+" lat(ilat) = "+lat(ilat))
 print("ilon = "+ilon+" StLon = "+StLon(0)+" lon(ilon) = "+lon(ilon))

 P2 = P1
 P2(:, 0) = var1_mon_mean(:, ilat, ilon)
 P2(:, 1) = var1_mon_std(:, ilat, ilon)
 
 opt2 = True
 opt2@fout = "US_UMB_nearest_grid_ET_mon_climo.txt"
 fmtx = "2f15.8"
 write_matrix(P2, fmtx, opt2)

 ;**********Point Observations *************************************************** 
 ;***** Obs data is in half hourly frequecy************************************
 ;***** We need to convert it into monthly then do cliamtology calculations using 5 yres data********
 
  obsName = "AMF_USUMB"

  obsVersion = "L4_h_V002"

  obsDir = "/glade/p/cesm/lmwg/ObsData/TowerData/"+obsName

  AnaYr = (/"2000", "2001", "2002", "2003", "2004"/)
  
  mon_Ndat = (/31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31/)
  mon_Sday = (/0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334/)

  P3 = new((/12, 5/), "float", -9999.0)

  do i = 0, 4
    obsFileName = obsName+"_"+AnaYr(i)+"_"+obsVersion+".nc"
    print(obsFileName)
    fo = addfile(obsDir+"/"+obsFileName, "r")
    varObs1 = fo->Le_f
    printVarSummary(varObs1)
    do j = 0, 11
       sti = mon_Sday(j) * 48
       eni = sti + mon_Ndat(j) * 48 -1
       P3(j, i) = (/dim_avg_n(varObs1(sti:eni), 0)/)
    end do
    delete(fo)
    delete(varObs1)
    delete(obsFileName)
  end do

 P4 = P1
 P4(:, 0) = dim_avg_n(P3, 1)
 P4(:, 1) = dim_stddev_n(P3, 1)

 opt3 = True
 opt3@fout = "US_UMB_obs_ET_mon_climo.txt"
 fmtx = "2f15.8"
 write_matrix(P4, fmtx, opt3)


;*****************making annual time seris****

 var1_ann = var1(0:4, :, :)  ;***this way new variables have necessary dimensions e.g. lat and lon
                             ;*** you can cahnge time dimensions depending upon the number of years for your run

 do i = 0, 4
    sti = i*12
    endi = sti + 11
    var1_ann(i, :, :) = (/dim_avg_n_Wrap(var1(sti:endi, :, :), 0)/)
 end do

 var1_ann_avg = dim_avg_n_Wrap(var1_ann, 0)     ;**** _Wrap is necessary because that way it also copies the metadata
 printVarSummary(var1_ann_avg)
 
 var1_ann_std = dim_stddev_n_Wrap(var1_ann, 0)

 printVarSummary(var1_ann_std)

;***Now we have two dimensional vairables var1_ann_avg, and var1_ann_std****************************************
;***we want to plot them ****************************************************************************************

 wks = gsn_open_wks("x11", "climatology_plot1_mw_usa_us_umb")

 gsn_define_colormap(wks, "cosam")     ; you can select your favorate coolor from NCL color tables

 ;gsn_reverse_colormap(wks)  ;****incase you want to reverse the color map

 res = True                  ; Define resources for the plot

 res@gsnDraw            = False             ; don't draw yet           ; these resources are necessary when you draw a panel plot
 res@gsnFrame           = False             ; don't advance frame yet

 res@gsnMaximize = True
 
 res@mpLimitMode          = "LatLon"      ; these resources are helful if you want to plot only a specfic region
 res@mpMinLatF            = 30
 res@mpMaxLatF            = 57
 res@mpMinLonF            = -100
 res@mpMaxLonF            =  -75

 ;res@mpOutlineBoundarySets = "Geophysical"
 res@mpOutlineBoundarySets = "GeophysicalAndUSStates"          ; turn on state boundaries
 res@mpGeophysicalLineColor = "black"
 res@mpUSStateLineColor = "black"
 
 res@pmTickMarkDisplayMode = "Always"

 res@cnFillOn = True
 res@cnLinesOn = False
 res@cnFillMode = "RasterFill"
 res@cnLineLabelsOn = False

 res@gsnSpreadColors = True

 res@lbOrientation = "Horizontal"

 res@lbBoxLinesOn         = False           ; Turn off labelbar box lines
 res@lbLabelAutoStride    = True            ; Control labelbar labels.


 ; res@lbLabelBarOn = False                 ; becomes useful in a panel plot


 ;*******SECTION A*******************************************
 ; ***first plot by commenting all the res in section A****
 ; *** the decide which maximum and minimum value you want to assign *****
 ; **** accordingly decide the min, max and stide for manual cn level selction *****
 res@cnLevelSelectionMode = "ManualLevels"
 res@cnMinLevelValF =  0.0
 res@cnMaxLevelValF =  80.0
 res@cnLevelSpacingF = 8.0

 ;*********** END OF SECTION A****************************************

  plot = new(2, graphic)                    ; if you have more than one plot then this is useful

 plot(0) = gsn_csm_contour_map(wks, var1_ann_avg, res)

 ;****Polygon Plot************

  gsres = True
  gsres@gsLineColor = "black"
  gsres@gsLineThicknessF = 5.0

  dum1 = new(1, graphic)
 
  do i = 0, 0
     dum1(i) = gsn_add_polyline(wks, plot(0), (/lon({lonRegL(i)}), lon({lonRegR(i)}), lon({lonRegR(i)}), lon({lonRegL(i)}), lon({lonRegL(i)})/), (/lat({latRegL(i)}), lat({latRegL(i)}), lat({latRegH(i)}), lat({latRegH(i)}), lat({latRegL(i)})/), gsres)
  end do

 ;****Polymarker Plot ************

   polyres                   = True
   polyres@gsMarkerIndex     = 15          ; polymarker style
   polyres@gsMarkerSizeF     = 25.          ; polymarker size
   polyres@gsMarkerColor     = "Blue"
   polyres@gsMarkerThicknessF = 3.0

  dum2    = gsn_add_polymarker(wks,plot(0),275.2862,45.5598,polyres)

 polyres@gsMarkerColor     = "Red"

  ;dum3 = gsn_add_polymarker(wks,plot(0),lon(ilon),lat(ilat),polyres)




;************************************************************************
 draw(plot(0))
 frame(wks)







